@@ -75,13 +75,15 @@ class PixelMapFit:
     
     def __init__(self, targetpixelfile, gaia=True, magnitude_limit=18, 
                  frequencies=[], frequnit=u.uHz, principal_components = 5, 
-                 aperture=None, method = 'Gaussian', sigma=None,pca_only = False, **kwargs):
+                 aperture=None, method = 'PRF', sigma=None,pca_only = False, **kwargs):
         
         self.tpf = targetpixelfile
         self.method = method
         #Defining an aperture that will be used in plotting and making empty 2-d arrays of the correct size for masks
         self.aperture = aperture
         self.pca_only = pca_only
+        self.principal_components = principal_components
+        self.frequency_list = np.asarray((frequencies*frequnit).to(1/u.d))
         if self.pca_only == True:
             self.raw_lc1 = self.tpf.to_lightcurve(aperture_mask=self.aperture)
             self.quality_mask = [np.isfinite(self.raw_lc1['flux']*self.raw_lc1['flux_err'])]
@@ -92,6 +94,7 @@ class PixelMapFit:
 
                 rc = lk.RegressionCorrector(self.raw_lc)
                 self.corrected_lc = rc.correct(self.dm.append_constant())
+                pgs = [lk.LightCurve(time = self.tpf.time.value[self.quality_mask[0]][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)],flux =self.dm.values.T[i]).to_periodogram() for i in np.arange(0,len(self.dm.values.T))]
                 fig,ax = plt.subplots(1,2,figsize=(14,5),sharey=True)
                 ax[0].plot(self.tpf.time.value[self.quality_mask[0]][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)], self.dm.values*1 + np.arange(self.principal_components)*0.2)
                 ax[0].set_title(r'Principal Components Contributions')
@@ -130,8 +133,8 @@ class PixelMapFit:
             self.corrected_lc = self.raw_lc
             
         #self.corrected_lc = corrected_lc.remove_outliers()
-        self.frequency_list = np.asarray((frequencies*frequnit).to(1/u.d))
-        self.principal_components = principal_components
+        
+        
         
         def Obtain_Initial_Phase(tpf,corrected_lc,frequency_list):
 
@@ -414,7 +417,7 @@ class PixelMapFit:
                         res = []
                         for i in np.arange(len(frequencies)):
                             height = params['height{0:d}'.format(i)]
-                            model = height*self.prf.locate(x+.5, y+.5, (self.size[0],self.size[1]))
+                            model = height*self.prf.locate(x, y, (self.size[0],self.size[1]))
 
                             res.extend( [(amp[i].reshape(self.size)-model) / amperr[i].reshape(self.size)])
 
@@ -492,7 +495,7 @@ class PixelMapFit:
         if self.principal_components==None:
             pass
         else:
-            
+            pgs = [lk.LightCurve(time = self.tpf.time.value[self.quality_mask[0]][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)],flux =self.dm.values.T[i]).to_periodogram() for i in np.arange(0,len(self.dm.values.T))]
             fig,ax = plt.subplots(1,2,figsize=(14,5),sharey=True)
             ax[0].plot(self.tpf.time.value[self.quality_mask[0]][np.where(self.raw_lc1[self.quality_mask[0]].quality ==0)], self.dm.values*1 + np.arange(self.principal_components)*0.2)
             ax[0].set_title(r'Principal Components Contributions')
